import uuid

from django.db import models
from django.contrib.auth import get_user_model
from django.utils.translation import gettext as _

from .webhooks import register_webhook_handler
from .webhook_handlers import payment_created, payment_changed

user_model = get_user_model()


class Payment(models.Model):

    class STATES(object):
        PENDING = 'pending'
        SETTLED = 'settled'
        FAILED = 'failed'
        RETRYING = 'retrying'
        REFUNDED = 'refunded'

    STATE_CHOICES = (
        (STATES.PENDING, _('Pending')),
        (STATES.SETTLED, _('Settled')),
        (STATES.FAILED, _('Failed')),
        (STATES.RETRYING, _('Retrying')),
        (STATES.REFUNDED, _('Refunded')),
    )


    KEYS_TO_COPY = ['description', 'reference', 'amount', 'currency']

    uuid = models.CharField(max_length=255, unique=True, default=uuid.uuid4)
    description = models.CharField(max_length=1024, blank=True, null=True)
    created_at = models.DateTimeField(auto_now_add=True, editable=False)
    updated_at = models.DateTimeField(auto_now=True, blank=True, null=True, editable=False)
    state= models.CharField(max_length=20, choices=STATE_CHOICES, default=STATES.PENDING)
    reference = models.CharField(max_length=255)
    amount = models.DecimalField(max_digits=19, decimal_places=4, blank=True, null=True)
    currency = models.CharField(max_length=10, blank=True, null=True)
    user = models.ForeignKey(user_model, blank=True, null=True, on_delete=models.SET_NULL, related_name='payments')

    def as_dict(self):
        return {
            'uuid': self.uuid,
            'description': self.description,
            'created_at': self.created_at,
            'updated_at': self.updated_at,
            'state': self.state,
            'reference': self.reference,
            'amount': self.amount,
            'currency': self.currency,
            'user': self.user.id if self.user else None,
        }

register_webhook_handler(payment_created)
register_webhook_handler(payment_changed)

# @register_snippet
# class Subscription(models.Model):
#     user = models.ForeignKey('auth.User', blank=True, null=True, on_delete=models.SET_NULL, related_name='subscriptions')
#     reference = models.CharField(max_length=255)
#     active_until = models.DateTimeField(blank=True, null=True)
#     token = models.CharField(max_length=100, blank=True)
#     active = models.BooleanField(default=False)
#     is_on_trial = models.BooleanField(default=False)
#     plan = models.ForeignKey('askell.Plan', to_field='plan_id', on_delete=models.CASCADE, null=True, blank=True)
#     description = models.CharField(max_length=1024, blank=True, null=True)
#     subscription_id = models.PositiveIntegerField(unique=True, null=True, blank=True)
    
#     def __str__(self):
#         if self.user:
#             return f"Subscription for {self.user.username} ({self.user.id})"
#         else:
#             return f"Subscription for {self.reference} (no user linked)"

#     panels = [
#         FieldPanel('user'),
#         FieldPanel('reference'),
#         FieldPanel('active_until'),
#         FieldPanel('token'),
#         FieldPanel('active'),
#         FieldPanel('is_on_trial'),
#         FieldPanel('plan'),
#         FieldPanel('description'),
#         FieldPanel('subscription_id'),
#     ]


class Plan(models.Model):
    plan_id = models.PositiveIntegerField(primary_key=True)
    name = models.CharField(max_length=512)
    alternative_name = models.CharField(max_length=512, blank=True, null=True)
    reference = models.CharField(max_length=512, blank=True, null=True)
    interval = models.CharField(max_length=50, blank=True, null=True)
    interval_count = models.IntegerField(blank=True, null=True)
    amount = models.DecimalField(max_digits=19, decimal_places=4, blank=True, null=True)
    currency = models.CharField(max_length=10, blank=True, null=True)
    trial_period_days = models.IntegerField(blank=True, null=True)
    description = models.TextField(blank=True, null=True)
    enabled = models.BooleanField(default=False)
    private = models.BooleanField(default=False)
    electronic_only = models.BooleanField(default=True)

    def __str__(self):
        return self.name


# @register_snippet
# class PlanGroups(models.Model):

#     plan = ParentalKey(Plan, related_name='groups', on_delete=models.CASCADE)
#     group = models.ForeignKey(Group, on_delete=models.CASCADE)

#     panels = [
#          MultiFieldPanel(
#             [
#                 FieldPanel("plan"),
#                 FieldPanel("group"),
#             ],
#             heading="Plan / Group relations",
#         ),
#     ]

#     def __str__(self):
#         return f"{self.plan.name} -> {self.group.name}"




# Generated by Django 4.2.4 on 2023-12-22 15:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('askell', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='payment',
            name='amount',
            field=models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='currency',
            field=models.CharField(blank=True, max_length=10, null=True),
        ),
    ]



import hmac
import base64
import json
import logging
import hashlib
import requests

from django.http import HttpResponse
from django.views.decorators.csrf import csrf_exempt
from django.utils.decorators import method_decorator
from django.contrib.auth.decorators import login_required

from django.utils.translation import gettext as _
from rest_framework.views import APIView
from rest_framework.response import Response

from .settings import ASKELL_WEBHOOK_SECRET, ASKELL_ENDPOINT, ASKELL_SECRET_KEY
from .utils import get_customer_reference_from_user
from .models import Payment
from .webhooks import run_webhook_handlers

logger = logging.getLogger('django-askell')


WEBHOOK_SECRET = ASKELL_WEBHOOK_SECRET.encode()
WEBHOOK_DIGEST_TYPE = 'sha512'

# also available at `thorn.utils.hmac.verify`
def verify(hmac_header, digest_method, secret, message):
    logger.debug(f'''Verifying webhook signature:
                    HMAC header: {hmac_header}
                    Digest method: {digest_method}
                    Secret: {secret}
                    Message: {message}
                ''')
    digestmod = getattr(hashlib, digest_method)
    signed = base64.b64encode(
        hmac.new(secret, message, digestmod).digest(),
    ).strip()
    return hmac.compare_digest(signed, hmac_header)


class WebhookHandlerView(APIView):

    @method_decorator(csrf_exempt)
    def post(self, request, format=None):
        digest = request.META.get('HTTP_HOOK_HMAC').encode()
        event = request.META.get('HTTP_HOOK_EVENT')
        body = request.body
        error_message = 'Could not verify webhook signature. Check your webhook secret and digest type.'

        logger.debug(f'''Webhook received:
                     Event: {event}
                     Body: {body}
                     Digest: {digest}''')

        if verify(digest, WEBHOOK_DIGEST_TYPE, WEBHOOK_SECRET, body):
            payload = json.loads(body)
            event = payload['event']
            data = payload['data']

            if run_webhook_handlers(request, event, data):
                return Response({'status': 'success'}, status=200)
            else:
                error_message = 'Could not run webhook handlers.'
        else:
            logger.warning(f'Webhook signature verification failed: {error_message}')

        return Response({'status': 'error', 'error': error_message}, status=400)


@method_decorator(login_required, name='dispatch')
class UpdateCardView(APIView):


    def post(self, request, format=None):

        headers = {"Authorization": f"Api-Key {ASKELL_SECRET_KEY}"}
        
        customer_reference = get_customer_reference_from_user(request.user)

        post_data = {
            "customer_reference": customer_reference,
            "token": request.data['token'],
        }

        url = f"{ASKELL_ENDPOINT}/customers/paymentmethod/"
        r = requests.post(url, headers=headers, json=post_data)
        response = r.json()

        if r.status_code < 300:
            return Response({'status': 'success', 'response': response})
        else:
            return Response({'status': 'error', 'message': response['error']}, status=r.status_code)


@method_decorator(login_required, name='dispatch')
class TransactionReceiptView(APIView):

    def get(self, request, uuid=None, format=None):

        try:

            headers = {"Authorization": f"Api-Key {ASKELL_SECRET_KEY}"}

            url = f"{ASKELL_ENDPOINT}/transactions/{uuid}/receipt/"
            r = requests.get(url, headers=headers)
            
            pdf_response = r.json()

            if r.status_code == 200:
                response = HttpResponse(base64.b64decode(pdf_response['receipt']), content_type='application/pdf;')
                response['Content-Disposition'] = f'inline; filename={pdf_response["filename"]}.pdf'
                return response
            else:
                return Response({'status': 'error', 'message': pdf_response['error']}, status=r.status_code)
        except Exception as e:
            print(e)
            return Response({'status': 'error', 'message': f"{_('Server error. Please try again later.')} {e} {pdf_response}"}, status=r.status_code)


@method_decorator(login_required, name='dispatch')
class CustomerView(APIView):

    def get(self, request):

        try:
            headers = {"Authorization": f"Api-Key {ASKELL_SECRET_KEY}"}
            customer_reference = get_customer_reference_from_user(request.user)
            
            if customer_reference:
                url = f"{ASKELL_ENDPOINT}/customers/{customer_reference}/"
                r = requests.get(url, headers=headers)
                response = r.json()

                if r.status_code == 200:
                    return Response({'status': 'success', 'response': response})
                else:
                    return Response({'status': 'error', 'message': response['error']}, status=r.status_code)
            else:
                return Response({'status': 'success', 'response': {}})
        except Exception as e:
            print(e)
            return Response({'status': 'error', 'message': _('Server error. Please try again later.')}, status=400)
        
    
    def post(self, request, format=None):
        try:
            headers = {"Authorization": f"Api-Key {ASKELL_SECRET_KEY}"}
            customer_reference = get_customer_reference_from_user(request.user)

            post_data = {
                "customer_reference": customer_reference,
                "email": request.user.email,
                "first_name": request.user.first_name,
                "last_name": request.user.last_name,
            }

            url = f"{ASKELL_ENDPOINT}/customers/"
            r = requests.post(url, headers=headers, json=post_data)
            response = r.json()

            if r.status_code < 300:
                return Response({'status': 'success', 'response': response})
            else:
                return Response({'status': 'error', 'message': response['error']}, status=r.status_code)
            
        except Exception as e:
            print(e)
            return Response({'status': 'error', 'message': _('Server error. Please try again later.')}, status=r.status_code)
        
    

@method_decorator(login_required, name='dispatch')
class PaymentMethodView(APIView):
    
    def post(self, request, format=None):
        customer_reference = get_customer_reference_from_user(request.user)
        headers = {"Authorization": f"Api-Key {ASKELL_SECRET_KEY}"}
        c_response = requests.get(f"{ASKELL_ENDPOINT}/customers/{customer_reference}/", headers=headers)
        if c_response.status_code == 404:
            s = CustomerView().post(request, format=None)
            if s.status_code > 299:
                return s

        return UpdateCardView().post(request, format=None)


@method_decorator(login_required, name='dispatch')
class PaymentView(APIView):

    def get(self, request, uuid=None):
        try:
            payment = Payment.objects.filter(uuid=uuid).first()
            if payment:
                return Response({'status': 'success', 'response': payment.as_dict()})
            else:
                return Response({'status': 'error', 'response': {}})
        except Exception as e:
            print(e)
            return Response({'status': 'error', 'message': _('Server error. Please try again later.')}, status=500)

    def post(self, request):
        try:
            headers = {"Authorization": f"Api-Key {ASKELL_SECRET_KEY}"}
            customer_reference = get_customer_reference_from_user(request.user)

            if customer_reference:
                url = f"{ASKELL_ENDPOINT}/customers/{customer_reference}/paymentmethod/"
                r = requests.post(url, headers=headers, json=request.data)
                    
                response = r.json()

                if r.status_code == 201:
                    payment_data = {key: response[key] for key in Payment.KEYS_TO_COPY}
                    payment_data['user'] = request.user

                    payment, created = Payment.objects.get_or_create(**payment_data)
                    return Response({'status': 'success', 'response': payment.as_dict()}, status=201)
                else:
                    return Response({'status': 'error', 'message': response['error']}, status=r.status_code)
            else:
                return Response({'status': 'success', 'response': {}})
        except Exception as e:
            print(e)
            return Response({'status': 'error', 'message': _('Server error. Please try again later.')}, status=r.status_code)
        

@method_decorator(login_required, name='dispatch')
class CheckoutView(APIView):

    def post(self, request):
        try:
            headers = {"Authorization": f"Api-Key {ASKELL_SECRET_KEY}"}

            post_data = {
                "plan": request.data['plan'],
                "capture_only": request.data.get('capture_only', False),
            }

            url = f"{ASKELL_ENDPOINT}/checkouts/"
            r = requests.post(url, headers=headers, json=post_data)
            response = r.json()

            if r.status_code < 300:
                return Response({'status': 'success', 'response': response})
            else:
                return Response({'status': 'error', 'message': response['error']}, status=r.status_code)

        except Exception as e:
            return Response({'status': 'error', 'message': _('Server error. Please try again later.')}, status=r.status_code)



# Create your models here.
from askell.models import Payment, Plan

from wagtail.admin.panels import FieldPanel
from wagtail.snippets.models import register_snippet
from wagtail.snippets.views.snippets import SnippetViewSet
from wagtail.permission_policies import ModelPermissionPolicy
from wagtail.snippets.views.snippets import CreateView


class CustomModelPermissionPolicy(ModelPermissionPolicy):

    def user_has_permission(self, user, action):
        """
        Override the permission check in the create view.
        The permission policy is what prevents the action button from showing up in the admin.
        """
        if action == 'add':
            return False
        return super().user_has_permission(user, action)


class CustomCreateView(CreateView):

    def user_has_permission(self, permission):
        """
        Override the permission check in the create view.
        If this was done with a custom permission policy, the superuser would be able to add snippets.
        """
        if permission == 'add':
            return False
        return self.permission_policy.user_has_permission(self.request.user, permission)


class PaymentViewSet(SnippetViewSet):
    model = Payment
    add_view_class = CustomCreateView
    permission_policy = CustomModelPermissionPolicy(Payment)

    panels = [
        FieldPanel('description'),
        FieldPanel('amount'),
        FieldPanel('currency'),
    ]

register_snippet(PaymentViewSet)


class PlanViewSet(SnippetViewSet):
    model = Plan
    add_view_class = CustomCreateView
    permission_policy = CustomModelPermissionPolicy(Plan)

    panels = [
        FieldPanel('description'),
        FieldPanel('amount'),
        FieldPanel('currency'),
    ]

register_snippet(PlanViewSet)



import logging

logger = logging.getLogger('django-askell')


WEBHOOK_HANDLERS = []

def get_webhook_handlers():
    return WEBHOOK_HANDLERS


def register_webhook_handler(func):
    if func not in WEBHOOK_HANDLERS:
        WEBHOOK_HANDLERS.append(func)
    return func


def run_webhook_handlers(request, event, data):
    for func in WEBHOOK_HANDLERS:
        logger.debug(f'Running webhook handler: {func.__name__}')
        if not func(request, event, data):
            logger.debug(f'Webhook handler {func.__name__} returned False.')
            return False
    logger.debug(f'Webhook handler {func.__name__} returned True.')
    return True


import os

from django.conf import settings

def get_setting(key, default_value=None):

    value = getattr(settings, key, None)

    if value:
        return value

    value = os.getenv(key)
    if value:
        return value

    return default_value

ASKELL_ACCOUNT_NAME = get_setting('ASKELL_ACCOUNT_NAME')
ASKELL_API_TOKEN = get_setting('ASKELL_API_TOKEN')
ASKELL_SECRET_KEY = get_setting('ASKELL_SECRET_KEY')
ASKELL_PUBLIC_KEY = get_setting('ASKELL_PUBLIC_KEY')
ASKELL_WEBHOOK_SECRET = get_setting('ASKELL_WEBHOOK_SECRET', '')
ASKELL_ENDPOINT = get_setting(
    'ASKELL_ENDPOINT', 'https://askell.is/api')

ASKELL_CUSTOMER_REFERENCE_USER_FIELD = get_setting(
    'ASKELL_CUSTOMER_REFERENCE_USER_FIELD', 'pk'
)

ASKELL_SUBSCRIPTION_REFERENCE_USER_FIELD = get_setting(
    'ASKELL_SUBSCRIPTION_REFERENCE_USER_FIELD', 'pk'
)


# Generated by Django 4.2.21 on 2025-05-23 11:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('askell', '0006_remove_payment_settled_remove_payment_settled_at_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Plan',
            fields=[
                ('plan_id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=512)),
                ('alternative_name', models.CharField(blank=True, max_length=512, null=True)),
                ('reference', models.CharField(blank=True, max_length=512, null=True)),
                ('interval', models.CharField(blank=True, max_length=50, null=True)),
                ('interval_count', models.IntegerField(blank=True, null=True)),
                ('amount', models.DecimalField(blank=True, decimal_places=4, max_digits=19, null=True)),
                ('currency', models.CharField(blank=True, max_length=10, null=True)),
                ('trial_period_days', models.IntegerField(blank=True, null=True)),
                ('description', models.TextField(blank=True, null=True)),
                ('enabled', models.BooleanField(default=False)),
                ('private', models.BooleanField(default=False)),
                ('electronic_only', models.BooleanField(default=True)),
            ],
        ),
    ]



from .settings import ASKELL_CUSTOMER_REFERENCE_USER_FIELD


def get_customer_reference_from_user(user):
    reference_field = getattr(user, ASKELL_CUSTOMER_REFERENCE_USER_FIELD)
    if callable(reference_field):
        return reference_field()
    else:
        return reference_field





def payment_created(request, event, data):
    from .models import Payment
    if event == 'payment.created':
        payment_data = {key: data[key] for key in Payment.KEYS_TO_COPY}
        uuid = data.pop('uuid')
        Payment.objects.get_or_create(uuid=uuid, defaults=payment_data)
    return True

def payment_changed(request, event, data):
    from .models import Payment
    if event == 'payment.changed':
        payment = Payment.objects.get(uuid=data['uuid'])
        for attr, val in data.items():
            setattr(payment, attr, val)
        payment.save()
    return True


from django.core.management.base import BaseCommand
from askell.client import client
from askell.models import Plan


class Command(BaseCommand):
    def handle(self, *args, **options):

        old_plans = Plan.objects.all()
        old_plans.update(enabled=False, private=True)

        plans = client.get_plans()

        for plan in plans:

            id = plan.pop('id')
            Plan.objects.update_or_create(plan_id=id, defaults=plan)



# Generated by Django 4.2.9 on 2024-01-05 10:48

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('askell', '0004_remove_payment_user_payment_uuid_alter_payment_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='payment',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='payments', to=settings.AUTH_USER_MODEL),
        ),
    ]



# Generated by Django 4.2.9 on 2024-01-05 10:47

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('askell', '0003_payment_user'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='payment',
            name='user',
        ),
        migrations.AddField(
            model_name='payment',
            name='uuid',
            field=models.CharField(default=uuid.uuid4, max_length=255, unique=True),
        ),
        migrations.AlterField(
            model_name='payment',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]



from django.urls import path

from .views import (
    CustomerView,
    CheckoutView,
    PaymentView,
    PaymentMethodView,
    TransactionReceiptView,
    UpdateCardView,
    WebhookHandlerView
)


urls = [
    path('customer/', CustomerView.as_view(), name='customer'),
    path('checkout/', CheckoutView.as_view(), name='checkout'),
    path('payment/', PaymentView.as_view(), name='payment'),
    path('payment/<uuid:uuid>/', PaymentView.as_view(), name='payment-detail'),
    path('payment_method/', PaymentMethodView.as_view(), name='payment-method'),
    path('transactions/<uuid:uuid>/receipt/', TransactionReceiptView.as_view(), name='transaction-receipt'),
    path('updatecard/', UpdateCardView.as_view(), name='update-card'),
    path('webhook/', WebhookHandlerView.as_view(), name='webhook'),
]



from django.contrib import admin

from .models import Payment, Plan


class PaymentAdmin(admin.ModelAdmin):
    model = Payment
    list_display = ('reference', 'created_at', 'state', 'amount', 'currency')
    list_filter = ('state', 'created_at')

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False


class PlanAdmin(admin.ModelAdmin):
    model = Plan
    list_display = ('name', 'amount', 'currency', 'enabled')
    list_filter = ('enabled', )

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False


admin.site.register(Payment, PaymentAdmin)
admin.site.register(Plan, PlanAdmin)



# Generated by Django 4.2.9 on 2024-01-09 09:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('askell', '0005_payment_user'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='payment',
            name='settled',
        ),
        migrations.RemoveField(
            model_name='payment',
            name='settled_at',
        ),
        migrations.AddField(
            model_name='payment',
            name='state',
            field=models.CharField(choices=[('pending', 'Pending'), ('settled', 'Settled'), ('failed', 'Failed'), ('retrying', 'Retrying'), ('refunded', 'Refunded')], default='pending', max_length=20),
        ),
        migrations.AddField(
            model_name='payment',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
    ]



import requests

# from .models import Plan, Subscription
from .settings import ASKELL_ENDPOINT, ASKELL_SECRET_KEY
from .utils import get_customer_reference_from_user


class AskellClient:

    def __init__(self, token, endpoint=None):
        self.TOKEN = token
        if endpoint:
            self.ENDPOINT = endpoint

    def _build_url(self, path):
        return "{}{}".format(self.ENDPOINT, path)

    @property
    def _auth(self):
        return {
            "Authorization": "Api-Key {}".format(self.TOKEN)
        }

    def get_subscriptions(self, id=None):
        path = '/subscriptions/'
        if id: 
            path = "/subscriptions/{}/".format(id)
        response = requests.get(self._build_url(path), headers=self._auth)
        return response.json()

    def get_plans(self, id=None):
        path = '/plans/'
        if id: 
            path = "/plans/{}/".format(id)
        response = requests.get(self._build_url(path), headers=self._auth)
        return response.json()
    
    def make_payment(self, user, amount, currency, reference, description=None, payment_options=None):
        customer_reference = get_customer_reference_from_user(user)
        path = '/payments/'
        data = {
            "customer_reference": customer_reference,
            "amount": amount,
            "currency": currency,
            "reference": reference,
        }
        if description:
            data["description"] = description

        if payment_options:
            # check that only allowed keys in dict are "payment_processor" == "claim", claimtemplate, claimrule or payment_date:
            allowed_keys = ["payment_processor", "claimtemplate", "claimrule", "payment_date", "payor_id"]
            for key in payment_options.keys():
                if key not in allowed_keys:
                    raise ValueError(f"Invalid key '{key}' in payment options. Allowed keys are: {allowed_keys}")
                if key == "payment_processor":
                    if payment_options[key] not in ["claim",]:
                        raise ValueError(f"Invalid value '{payment_options[key]}' for key 'payment_processor'. Allowed values are: ['claim']")
            data["payment_options"] = payment_options

        response = requests.post(self._build_url(path), headers=self._auth, json=data)
        return response.json()
    
    def get_payment(self, uuid):
        path = '/payments/{}/'.format(uuid)
        response = requests.get(self._build_url(path), headers=self._auth)
        return response.json()

    def get_customer(self, user):
        customer_reference = get_customer_reference_from_user(user)
        path = '/customers/{}/'.format(customer_reference)
        response = requests.get(self._build_url(path), headers=self._auth)

        if response.status_code == 200:
            return {'status': 'success', 'response': response.json()}
        else:
            return {'status': 'error', 'message': "Could not get customer"}


    def create_customer(self, user):
        customer_reference = get_customer_reference_from_user(user)
        path = '/customers/'
        data = {
            "customer_reference": customer_reference,
            "email": user.email,
            "first_name": user.first_name,
            "last_name": user.last_name,
        }
        response = requests.post(self._build_url(path), headers=self._auth, json=data)

        if response.status_code < 300:
            return {'status': 'success', 'response': response.json()}
        else:
            return {'status': 'error', 'message': "Could not create customer"}


    def create_checkout(self, plan_variant_id, capture_only=False):
        path = '/checkout/'
        data = {
            "plan_variant_id": plan_variant_id,
            "capture_only": capture_only
        }
        response = requests.post(self._build_url(path), headers=self._auth, json=data)
        return response.json()




client = AskellClient(ASKELL_SECRET_KEY, endpoint=ASKELL_ENDPOINT)



# Generated by Django 4.2.4 on 2023-12-22 12:05

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Payment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(blank=True, max_length=1024, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('settled_at', models.DateTimeField(blank=True, editable=False, null=True)),
                ('settled', models.BooleanField(default=False)),
                ('reference', models.CharField(max_length=255)),
            ],
        ),
    ]
